==> eslint-config-vue-preset-0.2.0.tgz: package/vue/strongly-recommended-e/fallback.js <==
"use strict"

module.exports = {
    rules: {
        "vue/comment-directive": "error",
        "vue/jsx-uses-vars": "error",
        "vue/no-async-in-computed-properties": "error",
        "vue/no-dupe-keys": "error",
        "vue/no-duplicate-attributes": "error",
        "vue/no-parsing-error": "error",
        "vue/no-reserved-keys": "error",
        "vue/no-shared-component-data": "error",
        "vue/no-side-effects-in-computed-properties": "error",
        "vue/no-template-key": "error",
        "vue/no-textarea-mustache": "error",
        "vue/no-unused-components": "error",
        "vue/no-unused-vars": "error",
        "vue/no-use-v-if-with-v-for": "error",
        "vue/require-component-is": "error",
        "vue/require-prop-type-constructor": "error",
        "vue/require-render-return": "error",
        "vue/require-v-for-key": "error",
        "vue/require-valid-default-prop": "error",
        "vue/return-in-computed-property": "error",
        "vue/use-v-on-exact": "error",
        "vue/valid-template-root": "error",
        "vue/valid-v-bind": "error",
        "vue/valid-v-cloak": "error",
        "vue/valid-v-else-if": "error",
        "vue/valid-v-else": "error",
        "vue/valid-v-for": "error",
        "vue/valid-v-html": "error",
        "vue/valid-v-if": "error",
        "vue/valid-v-model": "error",
        "vue/valid-v-on": "error",
        "vue/valid-v-once": "error",
        "vue/valid-v-pre": "error",
        "vue/valid-v-show": "error",
        "vue/valid-v-text": "error",
        "vue/attribute-hyphenation": "error",
        "vue/html-closing-bracket-newline": "error",
        "vue/html-closing-bracket-spacing": "error",
        "vue/html-end-tags": "error",
        "vue/html-indent": "error",
        "vue/html-quotes": "error",
        "vue/html-self-closing": "error",
        "vue/max-attributes-per-line": "error",
        "vue/multiline-html-element-content-newline": "error",
        "vue/mustache-interpolation-spacing": "error",
        "vue/name-property-casing": "error",
        "vue/no-multi-spaces": "error",
        "vue/no-spaces-around-equal-signs-in-attribute": "error",
        "vue/no-template-shadow": "error",
        "vue/prop-name-casing": "error",
        "vue/require-default-prop": "error",
        "vue/require-prop-types": "error",
        "vue/singleline-html-element-content-newline": "error",
        "vue/v-bind-style": "error",
        "vue/v-on-style": "error",
    },
}

==> eslint-config-vue-preset-0.5.0.tgz: package/vue/strongly-recommended-e/fallback.js <==
"use strict"

module.exports = {
    rules: {
        "vue/comment-directive": "error",
        "vue/experimental-script-setup-vars": "error",
        "vue/jsx-uses-vars": "error",
        "vue/custom-event-name-casing": "error",
        "vue/no-arrow-functions-in-watch": "error",
        "vue/no-async-in-computed-properties": "error",
        "vue/no-custom-modifiers-on-v-model": "error",
        "vue/no-dupe-keys": "error",
        "vue/no-dupe-v-else-if": "error",
        "vue/no-duplicate-attributes": "error",
        "vue/no-multiple-template-root": "error",
        "vue/no-mutating-props": "error",
        "vue/no-parsing-error": "error",
        "vue/no-reserved-keys": "error",
        "vue/no-shared-component-data": "error",
        "vue/no-side-effects-in-computed-properties": "error",
        "vue/no-template-key": "error",
        "vue/no-textarea-mustache": "error",
        "vue/no-unused-components": "error",
        "vue/no-unused-vars": "error",
        "vue/no-use-v-if-with-v-for": "error",
        "vue/no-v-for-template-key": "error",
        "vue/no-v-model-argument": "error",
        "vue/require-component-is": "error",
        "vue/require-prop-type-constructor": "error",
        "vue/require-render-return": "error",
        "vue/require-v-for-key": "error",
        "vue/require-valid-default-prop": "error",
        "vue/return-in-computed-property": "error",
        "vue/use-v-on-exact": "error",
        "vue/valid-template-root": "error",
        "vue/valid-v-bind-sync": "error",
        "vue/valid-v-bind": "error",
        "vue/valid-v-cloak": "error",
        "vue/valid-v-else-if": "error",
        "vue/valid-v-else": "error",
        "vue/valid-v-for": "error",
        "vue/valid-v-html": "error",
        "vue/valid-v-if": "error",
        "vue/valid-v-model": "error",
        "vue/valid-v-on": "error",
        "vue/valid-v-once": "error",
        "vue/valid-v-pre": "error",
        "vue/valid-v-show": "error",
        "vue/valid-v-slot": "error",
        "vue/valid-v-text": "error",
        "vue/attribute-hyphenation": "error",
        "vue/component-definition-name-casing": "error",
        "vue/html-closing-bracket-newline": "error",
        "vue/html-closing-bracket-spacing": "error",
        "vue/html-end-tags": "error",
        "vue/html-indent": "error",
        "vue/html-quotes": "error",
        "vue/html-self-closing": "error",
        "vue/max-attributes-per-line": "error",
        "vue/multiline-html-element-content-newline": "error",
        "vue/mustache-interpolation-spacing": "error",
        "vue/no-multi-spaces": "error",
        "vue/no-spaces-around-equal-signs-in-attribute": "error",
        "vue/no-template-shadow": "error",
        "vue/one-component-per-file": "error",
        "vue/prop-name-casing": "error",
        "vue/require-default-prop": "error",
        "vue/require-prop-types": "error",
        "vue/singleline-html-element-content-newline": "error",
        "vue/v-bind-style": "error",
        "vue/v-on-style": "error",
        "vue/v-slot-style": "error",
    },
}
